Prepare bootstrap input from a table of paired absolute and relative retro CPRS for the wastewater-informed and hospital-admissions only model.
Source:R/bootstrap_scores.R
convert_to_boostrap_input.RdPrepare bootstrap input from a table of paired absolute and relative retro CPRS for the wastewater-informed and hospital-admissions only model.
Value
A table that can be passed to bootstrap_crps_values().