Skip to contents

Plot bootstrapped CRPS ratios as pointintervals

Usage

plot_bootstrapped_score_ratios(
  replicates,
  point_estimates,
  by = NULL,
  connect_points = FALSE,
  order_by_point_estimate = FALSE
)

Arguments

replicates

Data frame of bootstrapped replicates, as the output of bootstrap_crps_values().

point_estimates

Data frame of point estimate ratios, with columns "model", "rel_crps", and a column with name equal to the by argument.

by

Stratification variable. Will become the x-axis of the plot. Default NULL (plot a single point-interval).

connect_points

Connect the points in the point intervals with lines? Boolean, default FALSE.

order_by_point_estimate

Order x-axis values by the value of the point estimate (ascending)? Boolean, default FALSE.

Value

The plot, as a ggplot object.