Create bootstrapped replicates to estimate uncertainty in the mean CRPS for the admissions-only and wastewater-informed models.
Source:R/bootstrap_scores.R
bootstrap_crps_values.RdProduces bootstrapped mean CRPS values for each value of the provided grouping variable.
Arguments
- scores
data frame of relative scores for the wastewater model with the admissions-only model as a baseline.
- n_replicates
Number of bootstrap replicate datasets to produce.
- by
Optional grouping column for bootstrap replicate datasets. Default
NULL(no grouping, produce replicates of the entire dataset).
Value
Tibble with the grouping column specified in by (if any)
and four other columns:
id: unique (within-group) identifier of the replicate dataset.bstrap_crps_ww: mean CRPS for the wastewater model in that replicate dataset.bstrap_crps_hosp: mean CRPS for the admissions-only model in that replicate dataset. sampled for that replicate.bstrap_rel_crps: ratio (ww / hosp) of the mean CRPS values for the two models in that replicate dataset.