Make a multi-panel figure summarizing relative performance with bootstrapping
Source:R/composite_figures.R
compose_bootstrap_fig.RdMake a multi-panel figure summarizing relative performance with bootstrapping
Usage
compose_bootstrap_fig(
abs_score_overall,
rel_score_overall,
rel_score_by_time,
rel_score_by_location
)Arguments
- abs_score_overall
plot of overall absolute scores with bootstrapped uncertainty intervals.
- rel_score_overall
plot of overall relative score with bootstrapped uncertainty intervals.
- rel_score_by_time
timeseries plot of relative score by forecast date with bootstrapped uncertainty intervals.
- rel_score_by_location
plot of (date-specific) score values by location with bootstrapped uncertainty intervals.